#
# spec file for package python-tableauserverclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-tableauserverclient
Version:        0.34
Release:        1.1
Summary:        Python library for working with the Tableau Server REST API
License:        MIT
URL:            https://github.com/tableau/server-client-python
Source:         https://github.com/tableau/server-client-python/archive/refs/tags/v%{version}.tar.gz#/tableauserverclient-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing-extensions}
BuildRequires:  %{python_module versioneer}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-defusedxml >= 0.7.1
Requires:       python-packaging >= 23.
Requires:       python-requests >= 2.31
Requires:       python-typing-extensions
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module defusedxml >= 0.7.1}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-subtests}
BuildRequires:  %{python_module requests >= 2.31}
BuildRequires:  %{python_module requests-mock >= 1.0}
# /SECTION
%python_subpackages

%description
A Python module for working with the Tableau Server REST API.

%prep
%setup -q -n server-client-python-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/tableauserverclient
%{python_sitelib}/tableauserverclient-%{version}.dist-info

%changelog
* Thu Nov 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.34:
  * Draft: Make urllib3 dependency more flexible
  * fix: queryset support for flowruns
  * docs: add docstrings to auth objects and endpoints
  * Set FILESIZE_LIMIT_MB via environment variables
  * added PulseMetricDefine cap
  * Adding project permissions handling for databases, tables and
    virtual connections
  * refactor request_options, add language param
  * ci: build on python 3.13
  * fix: handle 0 item response in querysets
- update to 0.33:
  * Add support for all types of monthly repeating schedules
  * Add workbook and datasource name attributes to JobItem Model
  * feat: group bulk edit
  * feat: add support for groupsets
  * feat: custom views dl pub
  * docs: add docstrings detailing the filter options
  * feat: tag everything
  * feat: get page and chunk size from env vars
  * feat: linked tasks
  * fix: Pager typing
- update to 0.32:
  * Bump urllib3 from 2.0.7 to 2.2.2 #1400
  * Allow setting page_size in .all and .filter #1417
  * Switch to absolute imports for favorites #1415
  * Switch to absolute imports for datasource #1416
  * Fix pop from empty list #1404
  * Ignore known internal warnings on tests #1407
  * Add support for changing project owner #1419
  * Add type hints to auth models #1403
  * Add typing to Pager #1390
  * Remove blocks of code and arguments that have been deprecated
  * Add usage to views.get_by_id #1383
  * Type hint QuerySet and QuerySetEndpoint #1399
  * No implicit reexport #1394
  * Allow combining PermissionRules #1381
  * Add size to datasource item #1397
  * Remove outdated dependencies #1398
  * Don't lowercase OData server addresses #1396
- update to 0.31:
  * Remove deprecated cgi package and switch to
    `email.message.Message` #1346
  * Allow viz height and width parameters #1348
  * Add support for System schedule type #1350
  * Add support for daily (24 hour) intervals for tasks #1355
  * Update Actions to include Python 3.12 and reduce duplicate
    test runs #1356
  * Add Data Acceleration and Data Freshness Policy support #1343
  * Add create cloud flow task support #1371
  * Pass parameters in request options #1372
  * Improve robustness of Pager results #1370
* Fri Mar 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.30:
  * Add all missing RequestOptions fields
  * make project nullable on datasource
  * add params to workbook publish method
  * add certification to publishing a datasource
  * add contentURL as a filter
  * adding sample file for favorites
  * Implement custom view objects
  * Fix bug in update-datasources before 3.15
  * catch exceptions from ServerInfo
  * add query-tagging attribute to connection
  * Add logic to retrieve Datarole and Metric permissions
  * Allow injection of sessions
  * Fix bug in exposing ExcelRequestOptions and test
  * fix behavior when url has no protocol
  * add option to pass specific datasources to delete extracts
  * allow user agent to be set by caller
  * Fix issues with connections publishing workbooks
  * Allow download to file-like objects
  * Add updated_at to JobItem class
  * fix revision references where xml returned does not match docs
  * Do not create empty connections list
  * Add custom session injection, Fix bug for http_options
  * fix filter for python 3, remove support for python 3.6
  * Add new samples and delete redundant ones
  * Clean up hidden_views by making it an attribute of WorkbookItem
  * Add type hints for workbook and data source revisions, data alerts,
    Favorites, Flows, groups, permissions, projects, flow runs, site,
    subscriptions, Users, webhooks
  * add get_by_id method and test for schedules
  * Allow null value for user quota tiers
  * fix workbook.delete_extract
  * add publish to pypi action
  * fix xml generation for items
  * Add Status, ParentProjectId and StartedAt filters for jobs endpoint
  * make project_id nullable to support "Personal Space" for workbooks
  * create single Credentials class
  * Reassign content on user removal
  * add redaction method to remove passwords when logging requests and
    responses, which can contain embedded credentials.
  * remove support for python 3.6 (add python version enforcement in setup.py)
  * Extract refreshable item IDs from job XML response
  * Do not eagerly fetch content when a stream was requested
  * Fix QuerySet slicing logic
  * add CRUD methods for default permissions
- Switch to pyproject macros.
- No more greedy globs in %%files.
- Switch to GitHub source URL.
* Wed Apr 20 2022 pgajdos@suse.com
- version update to 0.18.0
  [#]# 0.18.0 (6 April 2022)
  * Switched to using defused_xml for xml attack protection
  * added linting and type hints
  * improve experience with self-signed certificates/invalid ssl
  * updated samples
  * new item types: metrics, revisions for datasources and workbooks
  * features: support adding flows to schedules, exporting workbooks to powerpoint
  * fixes: delete extracts
  [#]# 0.17.0 (20 October 2021)
  * Added support for accepting parameters for post request of the metadata api (#850)
  * Fixed jobs.get_by_id(job_id) example & reference docs (#867, #868)
  * Fixed handling for workbooks in personal spaces which do not have projectID or Name  (#875)
  * Updated links to Data Source Methods page in REST API docs (#879)
  * Unified arguments of sample scripts (#889)
  * Updated docs for - links to Datasource API (#879) ,  sample scripts (#892) & metadata query (#896)
  * Added support for scheduling DataUpdate Jobs (#891)
  * Exposed the fileuploads API endpoint (#894)
  * Added a new sample & documentation for metadata API (#895, #896)
  * Added support to the package for getting flow run status, as well as the ability to cancel flow runs. (#884)
  * Added jobs.wait_for_job method (#903)
  * Added description support for datasources item (#912)
  * Dropped support for Python 3.5 (#911)
  [#]# 0.16.0 (15 July 2021)
  * Documentation updates (#800, #818, #839, #842)
  * Fixed data alert repr in subscription item (#821)
  * Added support for Data Quality Warning (#836)
  * Added support for renaming datasources (#843)
  * Improved Datasource tests (#843)
  * Updated catalog obfuscation field (#844)
  * Fixed revision limit field in site_item.py file (#847)
  * Added the Missing content permission field- LockedToProjectWithoutNested (#856)
- python-mock is not required for build
* Thu Feb 18 2021 John Vandenberg <jayvdb@gmail.com>
- Switch to using PyPI source
- Update to v0.15.0
  * Added support for python version 3.9
  * Added support for 'Get View by ID'
  * Added docs and test data to MANIFEST.in file
  * Added owner_id property to ProjectItem
  * Added support for skipping connection check while publishing workbook
  * Added support for 'Update Subscription'
  * Added support for 'Get Groups for a User'
  * Improved debug logging by including put/post request contents
  * Improved local and active-directory group creation
  * Improved 'Update Group' to match server requests/responses
  * Improved SiteItem with new properties and functions
  * Improved SubscriptionItem with new properties
  * Improved the 'type' property of TaskItem to convert server response to enum
  * Improved repository to use Github Actions for running tests/linter
  * Fixed data_acceleration field causing error in workbook update payload
* Thu Jan 21 2021 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.14.1
